from NodeGraphQt import BaseNode

class MultiplyNode(BaseNode):
    """
    Multiply Node:
      - Inputs: A, B
      - Output: Result (A * B)
    """
    __identifier__ = 'io.github.nicole.multiply'
    NODE_NAME = 'Multiply'

    def __init__(self):
        super(MultiplyNode, self).__init__()
        self.values = {}  # Ensure values is a dictionary.
        self.add_input('A')
        self.add_input('B')
        self.add_output('Result')
        self.value = 0

    def process_input(self):
        inputs = {}
        for port_name in ['A', 'B']:
            port = self.input(port_name)
            connected = port.connected_ports() if port is not None else []
            if connected:
                connected_port = connected[0]
                parent_node = connected_port.node()
                try:
                    inputs[port_name] = float(getattr(parent_node, 'value', 0))
                except (ValueError, TypeError):
                    inputs[port_name] = 0.0
            else:
                inputs[port_name] = 0.0
        result = inputs['A'] * inputs['B']
        self.value = result
        self.set_name(f"Multiply: {result}")
